function demo1(mix)

  % Compares cochleagrams of two sources before and after mixing.
    
  % set default mixture argument
  if (nargin==0)
    mix='FKB_275A_MBC_71ZA';
  end

  % Extract 1st and 2nd source name from mixture
  x=strfind(mix,'_');
  name1=mix(1:x(2)-1);
  name2=mix(x(2)+1:end);
  
  % Read cochleagrams - square to produce energies.
  coch1=read_cochleagram([name1, '.coch64.first']);
  coch1=uncompress(coch1);
  coch2=read_cochleagram([name2, '.coch64.second']);
  coch2=uncompress(coch2);
  coch12=read_cochleagram([mix, '.coch64.mixed']);
  coch12=flipud(coch12);
  coch12=uncompress(coch12);
  

  % Make composite colormap
  
  red = [ones(128, 1) ((127:-1:0)/127)' ((127:-1:0)/127)'];
  blue = [((127:-1:0)/127)' ((127:-1:0)/127)' ones(128, 1)];
  redbluegray=[red; blue; 1-gray];

  % Colour cochleagrams
  
  ccoch1= normalise(coch1,0,127);            % Red
  ccoch2= normalise(coch2,129, 127);         % Blue
  ccoch12= normalise(coch12,0,127);
  ccoch12s = ccoch12 + 129 * (coch1<coch2);  % Red/Blue segmentation
  ccoch12 = ccoch12+257;                     % Grey

  % Construct figure
  
  set(gcf,'Position', [380 310 640 510]);

  colormap(redbluegray);

  FONTSIZE=14;

  subplot(4,1,1);  
  do_subplot(ccoch1, 'Speaker one', FONTSIZE);
  subplot(4,1,2);
  do_subplot(ccoch2, 'Speaker two', FONTSIZE);
  subplot(4,1,3);
  do_subplot(ccoch12, 'Speaker one + speaker two', FONTSIZE);
  subplot(4,1,4);
  do_subplot(ccoch12s, 'Speaker one + speaker two (Segmented)', FONTSIZE);

  set(gca,'XTick',[20,40,60,80,100,120]);
  set(gca,'XTickLabel',{'0.2','0.4','0.6','0.8','1.0','1.2'});
  h=xlabel('Times [sec]');
  set(h,'FontSize',FONTSIZE);
  
  
function xn = normalise(x, minimum, range)
% Scale and offset x to have given minimum value and given range
  
  x=x-min(min(x));
  xn=minimum+x*range/max(max(x));
  
function cochleagram = read_cochleagram(name)  
% Read a 64 channel cochleagram
    
  fid=fopen(name,'r','l');
  cochleagram=fread(fid,[64,inf],'float');
  cochleagram=flipud(cochleagram);
  fclose(fid);
  
function do_subplot(coch, atitle, fontsize)
% Produce a cochleagram subplot
  
  image(coch);
  h=title(atitle);
  set(h,'FontSize',fontsize);
  set(gca,'YTick',[1,16,32,48,64]);
  set(gca,'YTickLabel',{'50','300','800','1800','3750'});
  axis xy
  set(gca,'XTick',[]);

function coch=uncompress(coch)
% Cochleagrams are stored as energy^0.3 so raise to power of 3.333
% to uncompress

  coch=coch.^3.333;