function demo1(mix)

  % Compares cochleagrams of two sources before and after mixing.
    
  % set default mixture argument
  if (nargin==0)
    mix='FKB_275A_MBC_71ZA';
  end

  % Extract 1st and 2nd source name from mixture
  x=strfind(mix,'_');
  name1=mix(1:x(2)-1);
  name2=mix(x(2)+1:end);
  
  
  % Read cochleagrams - square to produce energies.
  coch1=read_cochleagram([name1, '.coch64.first']);
  coch1=uncompress(coch1);
  coch2=read_cochleagram([name2, '.coch64.second']);
  coch2=uncompress(coch2);
  coch12=read_cochleagram([mix, '.coch64.mixed']);
  coch12=flipud(coch12);
  coch12=uncompress(coch12);
  

  % Make composite colormap
  
  red = [ones(128, 1) ((127:-1:0)/127)' ((127:-1:0)/127)'];
  blue = [((127:-1:0)/127)' ((127:-1:0)/127)' ones(128, 1)];
  redbluegray=[red; blue; 1-gray];

  % Colour cochleagrams
  mcoch12 = coch1.*(coch1>coch2) + coch2.*(coch2>coch1);
  
  ccoch1= normalise(coch1,0,127);            % Red
  ccoch2= normalise(coch2,129, 127);         % Blue
  ccoch12= normalise(coch12,257,127);        % Grey
  cmcoch12 = normalise(mcoch12,257,127);     % Grey
  
  % Construct figure
  
  set(gcf,'Position', [150 160 620 780]);

  colormap(redbluegray);

  FONTSIZE=14;

  subplot(5,1,1);  
  do_subplot(ccoch1, 'Speaker one', FONTSIZE);
  subplot(5,1,2);
  do_subplot(ccoch2, 'Speaker two', FONTSIZE);
  subplot(5,1,3);
  do_subplot(ccoch12, 'Speaker one + speaker two', FONTSIZE);
  hi=subplot(5,1,4);
  do_subplot(cmcoch12, 'max(speaker one, speaker two)', FONTSIZE);

  set(gca,'XTick',[20,40,60,80,100,120]);
  set(gca,'XTickLabel',{'0.2','0.4','0.6','0.8','1.0','1.2'});
  h=xlabel('Times [sec]');
  set(h,'FontSize',FONTSIZE);

  subplot(5,1,5);
  frame=70;  
  compare(coch1, coch2, coch12, frame, FONTSIZE);
  
  drawnow
  
  h=ylabel('Energy [dB]');
  set(h,'FontSize',FONTSIZE);

  % Allow user to double click on cochleagram figures to select different
  % spectral slices.
  
  while (frame>0)
    
    [x,y]=getpts(hi);
    frame=floor(x(1));
    
    if (frame>0)
      subplot(5,1,5);
      compare(coch1, coch2, coch12, frame, FONTSIZE);
    end
    
  end
  
  
function compare(coch1, coch2, coch12, frame, fontsize)
  % Compare spectral slices through the mixture and the individual
  % sources
    
  h1=plot_cochspec(coch1(:,frame),'r-');
  %  axis([0,64,1,20]);
  hold on;
  h2=plot_cochspec(coch2(:,frame),'b-');
  h3=plot_cochspec(coch12(:,frame),'k-');
  hold off;
  axis([0, 64, 1, 40]);
  legend([h1,h2,h3],{'Speaker 1', 'Speaker 2', 'Speaker 1+2'},1)
  h=xlabel(['Spectral slice at time ', num2str(frame/100), ' seconds. Double click cochleagram to plot again.']);
  set(h,'FontSize',fontsize);
  h=ylabel(['Energy (dB)']);
  set(h,'FontSize',fontsize);
  
function xn = normalise(x, minimum, range)
% Scale and offset x to have given minimum value and given range
  
  x=x-min(min(x));
  xn=minimum+x*range/max(max(x));
  
function cochleagram = read_cochleagram(name)  
% Read a 64 channel cochleagram
    
  fid=fopen(name,'r','l');
  cochleagram=fread(fid,[64,inf],'float');
  cochleagram=flipud(cochleagram);
  fclose(fid);

function h=plot_cochspec(cochspec, ls);
  
    cochspec_db = 10 * log10(max(1,cochspec));
    h=plot(cochspec_db,ls);

function hi=do_subplot(coch, atitle, fontsize)
% Produce a cochleagram subplot
  
  hi=image(coch);
  h=title(atitle);
  set(h,'FontSize',fontsize);
  set(gca,'YTick',[1,16,32,48,64]);
  set(gca,'YTickLabel',{'50','300','800','1800','3750'});
  axis xy
  set(gca,'XTick',[]);
  h=ylabel('Frequency [Hz]');
  set(h,'FontSize',fontsize);

function coch=uncompress(coch)
% Cochleagrams are stored as energy^0.3 so raise to power of 3.333
% to uncompress
  
  coch=coch.^3.333;